@@ -10,7 +10,7 @@ enum MyEnum {
     C,
 }
 
-#[derive(::poem_openapi::Schema, Debug, Eq, PartialEq)]
+#[derive(::poem_openapi::Object, Debug, Eq, PartialEq)]
 struct CreateUser {
     user: ::std::string::String,
     password: ::std::string::String,
@@ -38,7 +38,7 @@ enum CreateUserResponse {
     BadRequest(::poem_openapi::payload::PlainText),
 }
 
-fn bad_request_handler(err: ::poem_openapi::poem::Error) -> CreateUserResponse {
+fn bad_request_handler(err: ::poem_openapi::ParseRequestError) -> CreateUserResponse {
     CreateUserResponse::BadRequest(::poem_openapi::payload::PlainText(::std::format!(
         "error: {}",
         err
@@ -52,7 +52,7 @@ struct Api {
     >,
 }
 
-#[::poem_openapi::API]
+#[::poem_openapi::OpenApi]
 impl Api {
     /// Create a new user
     ///
